@@ -3,7 +3,7 @@
 //! # Basic Example
 //!
 //! ```rust
-//! # #[async_std::main] async fn main() -> Result<(), Box<dyn std::error::Error>> {
+//! # #[tokio::main] async fn main() -> Result<(), Box<dyn std::error::Error>> {
 //! // Get a Client for making request
 //! let client = ytextract::Client::new().await?;
 //!
@@ -16,13 +16,14 @@
 //! # }
 //! ```
 
-#![deny(missing_docs, rustdoc::missing_crate_level_docs, unsafe_code)]
+#![deny(missing_docs, unsafe_code, rustdoc::missing_crate_level_docs)]
 
 pub mod channel;
 mod client;
 mod error;
 mod id;
 pub(crate) mod player;
+pub mod playlist;
 pub mod stream;
 mod thumbnail;
 pub mod video;
@@ -31,6 +32,7 @@ pub(crate) mod youtube;
 pub use client::Client;
 pub use error::Error;
 pub use id::Id;
+pub use playlist::Playlist;
 pub use stream::Stream;
 pub use thumbnail::Thumbnail;
 pub use video::Video;
