@@ -2,7 +2,7 @@ use reqwest::Url;
 
 /// A Thumbnail.
 #[serde_with::serde_as]
-#[derive(Debug, serde::Deserialize)]
+#[derive(Debug, serde::Deserialize, Clone)]
 pub struct Thumbnail {
     /// The [`Url`] where the [`Thumbnail`] can be found.
     #[serde_as(as = "serde_with::DisplayFromStr")]
