@@ -5,6 +5,4 @@ use serde::Deserialize;
 pub struct YtCfg {
     pub player_js_url: String,
     pub innertube_api_key: String,
-    pub innertube_api_version: String,
-    pub innertube_context: serde_json::Value,
 }
